@@ -1,6 +1,5 @@
 
-import zmq
-
+import zmq.green as zmq
 context = zmq.Context()
 
 
